==> getsocial_flutter_sdk-7.6.0.tar.gz: lib/communities/queries/activitiesquery.dart <==
import '../../common/codable.dart';
import '../../common/userid.dart';
import '../../src/communitiesids.dart';
import '../communitiesentity.dart';
import 'announcementsquery.dart';
import '../pollstatus.dart';

class ActivitiesQuery extends Encodable {
  late CommunitiesIds ids;
  UserId? author;
  String? tag;
  int pollStatus = PollStatus.all;

  ActivitiesQuery(CommunitiesIds ids) {
    this.ids = ids;
  }

  static ActivitiesQuery feedOf(UserId id) {
    return ActivitiesQuery(CommunitiesIds.user(id));
  }

  static ActivitiesQuery inTopic(String id) {
    return ActivitiesQuery(CommunitiesIds.topic(id));
  }

  static ActivitiesQuery inAllTopics() {
    return ActivitiesQuery(CommunitiesIds.topics([]));
  }

  static ActivitiesQuery inGroup(String id) {
    return ActivitiesQuery(CommunitiesIds.group(id));
  }

  static ActivitiesQuery inAllGroups() {
    return ActivitiesQuery(CommunitiesIds.groups([]));
  }

  static ActivitiesQuery timeline() {
    return ActivitiesQuery(CommunitiesIds.timeline());
  }

  static ActivitiesQuery everywhere() {
    return ActivitiesQuery(CommunitiesIds.everywhere());
  }

  static ActivitiesQuery commentsToActivity(String id) {
    return ActivitiesQuery(CommunitiesIds.activity(id));
  }

  ActivitiesQuery byUser(UserId id) {
    this.author = id;
    return this;
  }

  ActivitiesQuery withTag(String tag) {
    this.tag = tag;
    return this;
  }

  ActivitiesQuery withPollStatus(int status) {
    this.pollStatus = status;
    return this;
  }

  AnnouncementsQuery? asAnnouncementsQuery() {
    switch (this.ids.type) {
      case CommunitiesEntityType.topic:
        return AnnouncementsQuery.inTopic(this.ids.ids.first);
      case CommunitiesEntityType.group:
        return AnnouncementsQuery.inGroup(this.ids.ids.first);
      case CommunitiesEntityType.app:
        return AnnouncementsQuery.timeline();
      case CommunitiesEntityType.user:
        return AnnouncementsQuery.forFeedOf(UserId.create(this.ids.ids.first));
    }
    return null;
  }

  Map<String, dynamic> toJSON() => {
        'ids': ids.toJSON(),
        'author': author?.toJSON(),
        'tag': tag,
        'pollStatus': pollStatus
      };
}

==> getsocial_flutter_sdk-7.8.1.tar.gz: lib/communities/queries/activitiesquery.dart <==
import '../../common/codable.dart';
import '../../common/userid.dart';
import '../../src/communitiesids.dart';
import '../communitiesentity.dart';
import 'announcementsquery.dart';
import '../pollstatus.dart';

class ActivitiesQuery extends Encodable {
  late CommunitiesIds ids;
  UserId? author;
  String? tag;
  int pollStatus = PollStatus.all;
  bool trending = false;

  ActivitiesQuery(CommunitiesIds ids) {
    this.ids = ids;
  }

  static ActivitiesQuery feedOf(UserId id) {
    return ActivitiesQuery(CommunitiesIds.user(id));
  }

  static ActivitiesQuery inTopic(String id) {
    return ActivitiesQuery(CommunitiesIds.topic(id));
  }

  static ActivitiesQuery inAllTopics() {
    return ActivitiesQuery(CommunitiesIds.topics([]));
  }

  static ActivitiesQuery inGroup(String id) {
    return ActivitiesQuery(CommunitiesIds.group(id));
  }

  static ActivitiesQuery inAllGroups() {
    return ActivitiesQuery(CommunitiesIds.groups([]));
  }

  static ActivitiesQuery timeline() {
    return ActivitiesQuery(CommunitiesIds.timeline());
  }

  static ActivitiesQuery everywhere() {
    return ActivitiesQuery(CommunitiesIds.everywhere());
  }

  static ActivitiesQuery commentsToActivity(String id) {
    return ActivitiesQuery(CommunitiesIds.activity(id));
  }

  ActivitiesQuery byUser(UserId id) {
    this.author = id;
    return this;
  }

  ActivitiesQuery withTag(String tag) {
    this.tag = tag;
    return this;
  }

  ActivitiesQuery withPollStatus(int status) {
    this.pollStatus = status;
    return this;
  }

  ActivitiesQuery onlyTrending(bool trending) {
    this.trending = trending;
    return this;
  }

  AnnouncementsQuery? asAnnouncementsQuery() {
    switch (this.ids.type) {
      case CommunitiesEntityType.topic:
        return AnnouncementsQuery.inTopic(this.ids.ids.first);
      case CommunitiesEntityType.group:
        return AnnouncementsQuery.inGroup(this.ids.ids.first);
      case CommunitiesEntityType.app:
        return AnnouncementsQuery.timeline();
      case CommunitiesEntityType.user:
        return AnnouncementsQuery.forFeedOf(UserId.create(this.ids.ids.first));
    }
    return null;
  }

  Map<String, dynamic> toJSON() => {
        'author': author?.toJSON(),
        'ids': ids.toJSON(),
        'pollStatus': pollStatus,
        'tag': tag,
        'trending': trending,
      };
}
